yakumo.nova.v2.quota_set.Manager

Package yakumo :: Package nova :: Package v2 :: Module quota_set :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for Quota sets in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for Quota sets in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.quota_set.Resource |
get(self, project=None, user=None) Get quota set for a project | source code
None |
update(self, project=`'``__UNDEF__``'`, user=`'``__UNDEF__``'`, cores=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`, floating_ips=`'``__UNDEF__``'`, injected_file_content_bytes=`'``__UNDEF__``'`, injected_file_path_bytes=`'``__UNDEF__``'`, injected_files=`'``__UNDEF__``'`, instances=`'``__UNDEF__``'`, key_pairs=`'``__UNDEF__``'`, metadata_items=`'``__UNDEF__``'`, ram=`'``__UNDEF__``'`, security_group_rules=`'``__UNDEF__``'`, security_groups=`'``__UNDEF__``'`, server_group_members=`'``__UNDEF__``'`, server_groups=`'``__UNDEF__``'`) Update quota set for a project | source code
None |
delete(self, project=None, user=None) Delete quota set for a project | source code
yakumo.nova.v2.quota_set.Resource |
get_default(self, project=None) Get default quota set for a project | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``]``
| _json_resource_key = ``'``quota_set``'``
| _url_resource_path = ``'``/os-quota-sets``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_json_resources_key`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get(self, project=None, user=None) | source code
Get quota set for a project Parameters: `project` (yakumo.project.Resource) - Project (required) `user` (yakumo.user.Resource) - User Returns: yakumo.nova.v2.quota_set.Resource Resource object Overrides: base.Manager.get

### update(self, project=`'``__UNDEF__``'`, user=`'``__UNDEF__``'`, cores=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`, floating_ips=`'``__UNDEF__``'`, injected_file_content_bytes=`'``__UNDEF__``'`, injected_file_path_bytes=`'``__UNDEF__``'`, injected_files=`'``__UNDEF__``'`, instances=`'``__UNDEF__``'`, key_pairs=`'``__UNDEF__``'`, metadata_items=`'``__UNDEF__``'`, ram=`'``__UNDEF__``'`, security_group_rules=`'``__UNDEF__``'`, security_groups=`'``__UNDEF__``'`, server_group_members=`'``__UNDEF__``'`, server_groups=`'``__UNDEF__``'`) | source code
Update quota set for a project Parameters: `project` (yakumo.project.Resource) - Project object (required) `user` (yakumo.user.Resource) - User object `cores` (int) - max number of cores `fixed_ips` (int) - max number of fixed IPs `floating_ips` (int) - max number of floating IPs `injected_file_content_bytes` (int) - max bytes of an injected file `injected_file_path_bytes` (int) - max path length of an injected file `injected_files` (int) - max number of injected files `instances` (int) - max number of instances `key_pairs` (int) - max number of key pairs `metadata_items` (int) - max number of metadata items `ram` (int) - max number of RAM `security_group_rules` (int) - max number of security group rules `security_groups` (int) - max number of security groups `server_group_members` (int) - max number of server group members `server_groups` (int) - max number of server groups Returns: None

### delete(self, project=None, user=None) | source code
Delete quota set for a project Parameters: `project` (yakumo.project.Resource) - Project `user` (yakumo.user.Resource) - User Returns: None

### get_default(self, project=None) | source code
Get default quota set for a project Parameters: `project` (yakumo.project.Resource) - Project Returns: yakumo.nova.v2.quota_set.Resource Default quota set

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('cores', 'cores', mapper.Noop), ('fixed_i
      ps', 'fixed_ips', mapper.Noop), ('floating_ips', 'floating_ips', mappe
      r.Noop), ('injected_file_content_bytes', 'injected_file_content_bytes'
      , mapper.Noop), ('injected_file_path_bytes', 'injected_file_path_bytes
      ', mapper.Noop), ('injected_files', 'injected_files', mapper.Noop), ('
      instances', 'instances', mapper.Noop), ('key_pairs', 'key_pairs', mapp
      er.Noop), ('metadata_items', 'metadata_items', mapper.Noop), ('ram', '
      ram', mapper.Noop), ('security_group_rules', 'security_group_rules', m
      ...